@@ -35,7 +35,7 @@ import re
 
 PY2 = sys.version_info[0] == 2
 
-VERSION = (0, 1, 0)
+VERSION = (0, 1, 1)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -232,7 +232,6 @@ def _bint_to_bytes(val, nbytes):    # Convert int value to big endian bytes.
                 b[nbytes -i -2] += 1
     return b''.join([chr(c) for c in b]) if PY2 else bytes(b)
 
-
 def _decode_column(data, oid, encoding):
     if data is None:
         return data
@@ -285,6 +284,11 @@ def _decode_column(data, oid, encoding):
         dt.replace(tzinfo=UTC())
         dt += datetime.timedelta(hours=offset)
         return dt
+    elif oid in (PG_TYPE_BYTEA, ):
+        assert data[:2] == u'\\x'
+        hex_str = data[2:]
+        ia = [int(hex_str[i:i+2], 16) for i in range(0, len(hex_str), 2)]
+        return b''.join([chr(c) for c in ia]) if PY2 else bytes(ia)
     elif oid in (PG_TYPE_TEXT, PG_TYPE_VARCHAR, PG_TYPE_NAME, PG_TYPE_JSON):
         return data
 
@@ -343,8 +347,12 @@ def escape_parameter(v):
     t = type(v)
     if v is None:
         return 'NULL'
-    elif (PY2 and t == unicode) or (not PY2 and t == str):
+    elif (PY2 and t == unicode) or (not PY2 and t == str):  # string
         return "'" + v.replace("'", "''") + "'"
+    elif PY2 and t == str:  # binary
+        return "'" + ''.join(['\\%03o' % (ord(c),) for c in v]) + "'::bytea"
+    elif t == bytes:        # binary
+        return "'" + ''.join(['\\%03o' % (c, ) for c in v]) + "'::bytea"
     elif t == bool:
         return u"'t'" if v else u"'f'"
     else:
@@ -443,7 +451,7 @@ class Connection(object):
         )
         self._flush()
 
-    def _process_messages(self, cur=None):
+    def _process_messages(self, obj=None):
         while True:
             code = self._read(1)
             ln = _bytes_to_bint(self._read(4)) - 4
@@ -477,9 +485,9 @@ class Connection(object):
                 DEBUG_OUTPUT("COMMAND_COMPLETE:", data[:-1].decode('ascii'))
             elif code == PG_B_ROW_DESCRIPTION:
                 DEBUG_OUTPUT("ROW_DESCRIPTION:", binascii.b2a_hex(data))
-                if cur is not None:
+                if obj is not None:
                     count = _bytes_to_bint(data[0:2])
-                    cur.description = [None] * count
+                    obj.description = [None] * count
                     n = 2
                     idx = 0
                     for i in range(count):
@@ -499,9 +507,9 @@ class Connection(object):
                             None,
                         )
                         n += 18
-                        cur.description[idx] = field
+                        obj.description[idx] = field
                         idx += 1
-                DEBUG_OUTPUT('\t\t', cur.description)
+                DEBUG_OUTPUT('\t\t', obj.description)
             elif code == PG_B_DATA_ROW:
                 DEBUG_OUTPUT("DATA_ROW:", binascii.b2a_hex(data))
                 n = 2
@@ -515,9 +523,9 @@ class Connection(object):
                         row.append(data[n:n+ln])
                         n += ln
                 for i in range(len(row)):
-                    row[i] = _decode_column(row[i], cur.description[i][1], self.encoding)
+                    row[i] = _decode_column(row[i], obj.description[i][1], self.encoding)
 
-                cur._rows.append(row)
+                obj._rows.append(row)
                 DEBUG_OUTPUT("\t\t", row)
             elif code == PG_B_NOTICE_RESPONSE:
                 DEBUG_OUTPUT("NOTICE_RESPONSE:", binascii.b2a_hex(data))
@@ -562,22 +570,22 @@ class Connection(object):
     def cursor(self):
         return Cursor(self)
 
-    def execute(self, cur, query, args=()):
+    def execute(self, obj, query, args=()):
         if args:
             escaped_args = tuple(escape_parameter(arg) for arg in args)
             query = query % escaped_args
         if not self.in_transaction:
             self._send_message(PG_F_QUERY, b"BEGIN\x00")
-            self._process_messages(cur)
+            self._process_messages(obj)
         DEBUG_OUTPUT('Connection::execute()', query)
         self._send_message(
             PG_F_QUERY,
             query.encode(self.encoding) + b'\x00',
         )
-        self._process_messages(cur)
+        self._process_messages(obj)
         if self.autocommit:
             self._send_message(PG_F_QUERY, b"COMMIT\x00")
-            self._process_messages(cur)
+            self._process_messages(obj)
 
     def set_autocommit(self, autocommit):
         self.autocommit = autocommit
